==> gtkpool_0.4.1.orig.tar.gz: gtkpool-0.4.1/gtkpool/options.h <==
/***************************************************************************
                          options.h  -  description
                             -------------------
    begin                : Tue Jan 8 2002
    copyright            : (C) 1999-2002 by Jacques Fortier & Brian Ashe
    email                : gtkpool@seul.org
 ***************************************************************************/

/***************************************************************************
 *                                                                         *
 *   This program is free software; you can redistribute it and/or modify  *
 *   it under the terms of the GNU General Public License as published by  *
 *   the Free Software Foundation; either version 2 of the License, or     *
 *   (at your option) any later version.                                   *
 *                                                                         *
 ***************************************************************************/

#include <gtk/gtk.h>
#include "application.h"
#include "support.h"

/* Options Dialog -- Displays and adjusts game play options */

// Create window and display stuff
GtkWidget *open_opt_dlg(Application *app);

// Close window
void od_close_event(GtkWidget *widget, gpointer data);
// Toggle hit moving balls
void moving_toggled_event(GtkWidget *widget, gpointer data);
// Toggle superhuman shots
void superhuman_toggled_event(GtkWidget *widget, gpointer data);
// Toggle game eight ball
void eb_toggled_event(GtkWidget *widget, Application *);
// Toggle game nine ball
void nb_toggled_event(GtkWidget *widget, Application *);
// Toggle game rotation
void ro_toggled_event(GtkWidget *widget, Application *);
// Toggle table black pearl
void bp_table_toggled_event(GtkWidget *widget, Application *);
// Toggle table black laquer
void bl_table_toggled_event(GtkWidget *widget, Application *);
// Toggle table maple burl
void mb_table_toggled_event(GtkWidget *widget, Application *);
// Toggle table mahogany
void ma_table_toggled_event(GtkWidget *widget, Application *);
// Redraw table after new selection
bool refresh_table(GtkWidget *widget, Application *app);

==> gtkpool_0.5.0.orig.tar.gz: gtkpool-0.5.0/gtkpool/options.h <==
/***************************************************************************
                          options.h  -  description
                             -------------------
    begin                : Tue Jan 8 2002
    copyright            : (C) 1999-2002 by Brian Ashe & Jacques Fortier
    email                : gtkpool@seul.org
 ***************************************************************************/

/***************************************************************************
 *                                                                         *
 *   This program is free software; you can redistribute it and/or modify  *
 *   it under the terms of the GNU General Public License as published by  *
 *   the Free Software Foundation; either version 2 of the License, or     *
 *   (at your option) any later version.                                   *
 *                                                                         *
 ***************************************************************************/

#include <gtk/gtk.h>
#include "application.h"
#include "support.h"

/**
  *@author Brian Ashe & Jacques Fortier
  */

/* Options Dialog -- Displays and adjusts game play options */

// Create window and display stuff
GtkWidget *open_opt_dlg(Application *app);

// Close window
void od_close_event(GtkWidget *widget, gpointer data);
// Toggle sound
void sound_toggled_event(GtkWidget *widget, gpointer data);
// Toggle hit moving balls
void moving_toggled_event(GtkWidget *widget, gpointer data);
// Toggle aiming line
void aimline_toggled_event(GtkWidget *widget, gpointer data);
// Toggle superhuman shots
void superhuman_toggled_event(GtkWidget *widget, gpointer data);
// Toggle game eight ball
void eb_toggled_event(GtkWidget *widget, Application *);
// Toggle game nine ball
void nb_toggled_event(GtkWidget *widget, Application *);
// Toggle game rotation
void ro_toggled_event(GtkWidget *widget, Application *);
// Toggle game no rules
void nr_toggled_event(GtkWidget *widget, Application *);
// Toggle table black pearl
void bp_table_toggled_event(GtkWidget *widget, Application *);
// Toggle table black laquer
void bl_table_toggled_event(GtkWidget *widget, Application *);
// Toggle table maple burl
void mb_table_toggled_event(GtkWidget *widget, Application *);
// Toggle table mahogany
void ma_table_toggled_event(GtkWidget *widget, Application *);
// Redraw table after new selection
bool refresh_table(GtkWidget *widget, Application *app);
